Crate tree_sitter_wdl_1

Crate tree_sitter_wdl_1 

This crate provides wdl language support for the [tree-sitter][] parsing library.

Enums

ParserError

Constants

GRAMMAR
The source of the WDL tree-sitter grammar description.
NODE_TYPES
The content of the node-types.json file for this grammar.

Functions

language
Returns the tree-sitter Language for this grammar.
parse_document
parser
Returns a Parser with the language set to language().